//@line 36 "/builds/releases/3.1b2-l10n/mozilla-central/l10n/es-ES/browser/firefox-l10n.js"

//@line 38 "/builds/releases/3.1b2-l10n/mozilla-central/l10n/es-ES/browser/firefox-l10n.js"

pref("general.useragent.locale", "es-ES");
